@@ -8,7 +8,7 @@ It provides functionality for
 """
 import asyncio
 import logging
-from typing import TYPE_CHECKING, Any, Iterator, Optional
+from typing import TYPE_CHECKING, Any, Dict, Iterator, Optional
 
 from xknx.remote_value import RemoteValueSwitch
 
@@ -65,11 +65,11 @@ class Switch(Device):
         super().__del__()
 
     @classmethod
-    def from_config(cls, xknx: "XKNX", name: str, config: Any) -> "Switch":
+    def from_config(cls, xknx: "XKNX", name: str, config: Dict[str, Any]) -> "Switch":
         """Initialize object from configuration structure."""
         group_address = config.get("group_address")
         group_address_state = config.get("group_address_state")
-        invert = config.get("invert")
+        invert = config.get("invert", False)
         reset_after = config.get("reset_after")
 
         return cls(
