@@ -14,7 +14,7 @@ It provides functionality for
 """
 from datetime import date, datetime
 from enum import Enum
-from typing import TYPE_CHECKING, Any, Callable, Iterator, Optional, Tuple
+from typing import TYPE_CHECKING, Any, Callable, Dict, Iterator, Optional, Tuple
 
 from xknx.remote_value import RemoteValue, RemoteValueSensor, RemoteValueSwitch
 
@@ -444,7 +444,7 @@ class Weather(Device):
         return WeatherCondition.EXCEPTIONAL
 
     @classmethod
-    def from_config(cls, xknx: "XKNX", name: str, config: Any) -> "Weather":
+    def from_config(cls, xknx: "XKNX", name: str, config: Dict[str, Any]) -> "Weather":
         """Initialize object from configuration structure."""
         group_address_temperature = config.get("group_address_temperature")
         group_address_brightness_south = config.get("group_address_brightness_south")
