@@ -3,12 +3,17 @@ Module for Serialization and Deserialization of a KNX Connetionstate Request inf
 
 Connectionstate requests are used to determine if a tunnel connection is still active and valid.
 """
+from typing import TYPE_CHECKING, List
+
 from xknx.exceptions import CouldNotParseKNXIP
 
 from .body import KNXIPBody
 from .hpai import HPAI
 from .knxip_enum import KNXIPServiceType
 
+if TYPE_CHECKING:
+    from xknx.xknx import XKNX
+
 
 class ConnectionStateRequest(KNXIPBody):
     """Representation of a KNX Connection State Request."""
@@ -18,21 +23,24 @@ class ConnectionStateRequest(KNXIPBody):
     service_type = KNXIPServiceType.CONNECTIONSTATE_REQUEST
 
     def __init__(
-        self, xknx, communication_channel_id: int = 1, control_endpoint: HPAI = HPAI()
+        self,
+        xknx: "XKNX",
+        communication_channel_id: int = 1,
+        control_endpoint: HPAI = HPAI(),
     ):
         """Initialize ConnectionStateRequest object."""
         super().__init__(xknx)
         self.communication_channel_id = communication_channel_id
         self.control_endpoint = control_endpoint
 
-    def calculated_length(self):
+    def calculated_length(self) -> int:
         """Get length of KNX/IP body."""
         return 2 + HPAI.LENGTH
 
-    def from_knx(self, raw):
+    def from_knx(self, raw: bytes) -> int:
         """Parse/deserialize from KNX/IP raw data."""
 
-        def info_from_knx(info):
+        def info_from_knx(info: bytes) -> int:
             """Parse info bytes."""
             if len(info) < 2:
                 raise CouldNotParseKNXIP("Info has wrong length")
@@ -44,10 +52,10 @@ class ConnectionStateRequest(KNXIPBody):
         pos += self.control_endpoint.from_knx(raw[pos:])
         return pos
 
-    def to_knx(self):
+    def to_knx(self) -> List[int]:
         """Serialize to KNX/IP raw data."""
 
-        def info_to_knx():
+        def info_to_knx() -> List[int]:
             """Serialize information bytes."""
             info = []
             info.append(self.communication_channel_id)
@@ -59,7 +67,7 @@ class ConnectionStateRequest(KNXIPBody):
         data.extend(self.control_endpoint.to_knx())
         return data
 
-    def __str__(self):
+    def __str__(self) -> str:
         """Return object as readable string."""
         return (
             '<ConnectionStateRequest CommunicationChannelID="{}", '
