@@ -6,6 +6,6 @@ Module for handling KNX primitves.
 
 """
 # flake8: noqa
-from .address import GroupAddress, GroupAddressType, PhysicalAddress
+from .address import GroupAddress, GroupAddressType, IndividualAddress
 from .address_filter import AddressFilter
-from .telegram import Telegram, TelegramDirection, TelegramType
+from .telegram import Telegram, TelegramDirection
